@@ -4,7 +4,7 @@ import asyncio
 import os
 from datetime import datetime, timezone
 from pathlib import Path
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Optional, Tuple
 from uuid import uuid4
 
 from .delivery import (
@@ -54,15 +54,10 @@ class Tracker:
         max_attempts = int(_get("AICM_MAX_ATTEMPTS", "3"))
         max_retries = int(_get("AICM_MAX_RETRIES", "5"))
         max_batch_size = int(_get("AICM_MAX_BATCH_SIZE", "1000"))
-        # ``AICM_DELIVERY_LOG_BODIES`` was the legacy environment variable name.
-        # Prefer the new ``AICM_LOG_BODIES`` but fall back to the old name for
-        # backward compatibility.
-        log_bodies_val = _get("AICM_LOG_BODIES") or _get(
-            "AICM_DELIVERY_LOG_BODIES", "false"
-        )
+        log_bodies_val = _get("AICM_LOG_BODIES", "false")
         log_bodies = str(log_bodies_val).lower() in {"1", "true", "yes", "on"}
 
-        raise_on_error_val = _get("AICM_RAISE_ON_ERROR", "true")
+        raise_on_error_val = _get("AICM_RAISE_ON_ERROR", "false")
         raise_on_error = str(raise_on_error_val).lower() in {"1", "true", "yes", "on"}
 
         db_path = _get("AICM_DB_PATH", str(ini_dir / "queue.db"))
@@ -118,60 +113,113 @@ class Tracker:
             )
 
         # Instance-level tracking metadata
-        self.client_customer_key: Optional[str] = None
+        self.customer_key: Optional[str] = None
         self.context: Optional[Dict[str, Any]] = None
 
     # ------------------------------------------------------------------
-    def set_client_customer_key(self, key: str | None) -> None:
-        """Update the ``client_customer_key`` used for tracking."""
-        self.client_customer_key = key
+    # Configuration Methods
+    # ------------------------------------------------------------------
+    def set_customer_key(self, key: str | None) -> None:
+        """Update the ``customer_key`` used for tracking."""
+        self.customer_key = key
 
     def set_context(self, context: Dict[str, Any] | None) -> None:
         """Update the ``context`` dictionary used for tracking."""
         self.context = context
 
     # ------------------------------------------------------------------
+    # Helper Methods
+    # ------------------------------------------------------------------
+    def _get_vendor_api_mapping(self, service_key: str) -> Tuple[str, str]:
+        """Extract vendor and api_id from service_key.
+
+        Returns:
+            Tuple of (vendor, api_id)
+        """
+        if "::" in service_key:
+            vendor = service_key.split("::")[0]
+            # Map vendor to api_id
+            vendor_to_api = {
+                "openai": "openai_chat",
+                "anthropic": "anthropic",
+                "amazon-bedrock": "amazon-bedrock",
+                "fireworks-ai": "openai_chat",  # Fireworks uses OpenAI-compatible API
+                "xai": "openai_chat",  # X.AI uses OpenAI-compatible API
+                "google": "gemini",
+            }
+            api_id = vendor_to_api.get(vendor, vendor)
+            return vendor, api_id
+        else:
+            # If no "::" found, assume it's already an api_id
+            return service_key, service_key
+
+    def _build_final_service_key(
+        self, service_key: str, api_id: str, response_or_chunk: Any
+    ) -> str:
+        """Build the final service_key from api_id and model if needed."""
+        if "::" not in service_key:
+            # service_key was actually an api_id, extract model from response
+            model = getattr(response_or_chunk, "model", None)
+            if model:
+                # Map api_id back to vendor
+                api_to_vendor = {
+                    "openai_chat": "openai",
+                    "openai_responses": "openai",
+                    "anthropic": "anthropic",
+                    "amazon-bedrock": "amazon-bedrock",
+                    "gemini": "google",
+                }
+                vendor = api_to_vendor.get(api_id, api_id)
+                return f"{vendor}::{model}"
+        return service_key
+
+    def _resolve_tracking_params(
+        self, customer_key: Optional[str], context: Optional[Dict[str, Any]]
+    ) -> Tuple[Optional[str], Optional[Dict[str, Any]]]:
+        """Resolve tracking parameters using instance defaults as fallbacks."""
+        resolved_key = customer_key if customer_key is not None else self.customer_key
+        resolved_context = context if context is not None else self.context
+        return resolved_key, resolved_context
+
     def _build_record(
         self,
-        api_id: str,
-        system_key: Optional[str],
+        service_key: str,
         usage: Dict[str, Any],
         *,
         response_id: Optional[str],
         timestamp: str | datetime | None,
-        client_customer_key: Optional[str],
+        customer_key: Optional[str],
         context: Optional[Dict[str, Any]],
     ) -> Dict[str, Any]:
         record: Dict[str, Any] = {
-            "api_id": api_id,
+            "service_key": service_key,
             "response_id": response_id or uuid4().hex,
             "timestamp": (
-                timestamp.isoformat()
+                str(timestamp.timestamp())
                 if isinstance(timestamp, datetime)
-                else timestamp or datetime.now(timezone.utc).isoformat()
+                else str(datetime.fromisoformat(timestamp).timestamp())
+                if isinstance(timestamp, str)
+                else str(datetime.now(timezone.utc).timestamp())
             ),
             "payload": usage,
         }
-        # Only include service_key when provided. Some server-side validators
-        # treat explicit null differently from an omitted field.
-        if system_key is not None:
-            record["service_key"] = system_key
-        if client_customer_key is not None:
-            record["client_customer_key"] = client_customer_key
+        if customer_key is not None:
+            record["customer_key"] = customer_key
         if context is not None:
             record["context"] = context
         return record
 
+    # ------------------------------------------------------------------
+    # Core Tracking Methods
     # ------------------------------------------------------------------
     def track(
         self,
-        api_id: str,
-        system_key: Optional[str],
+        service_key: str,
         usage: Dict[str, Any],
         *,
         response_id: Optional[str] = None,
         timestamp: str | datetime | None = None,
-        client_customer_key: Optional[str] = None,
+        customer_key: Optional[str] = None,
         context: Optional[Dict[str, Any]] = None,
     ) -> Any:
         """Track usage data.
@@ -181,18 +229,14 @@ class Tracker:
         ``{"queued": <count>}`` indicating the queue length.
         """
         # Use instance-level values as fallbacks if parameters are None
-        if client_customer_key is None:
-            client_customer_key = self.client_customer_key
-        if context is None:
-            context = self.context
+        customer_key, context = self._resolve_tracking_params(customer_key, context)
 
         record = self._build_record(
-            api_id,
-            system_key,
+            service_key,
             usage,
             response_id=response_id,
             timestamp=timestamp,
-            client_customer_key=client_customer_key,
+            customer_key=customer_key,
             context=context,
         )
         result = self.delivery.enqueue(record)
@@ -202,107 +246,106 @@ class Tracker:
 
     async def track_async(
         self,
-        api_id: str,
-        system_key: Optional[str],
+        service_key: str,
         usage: Dict[str, Any],
         *,
         response_id: Optional[str] = None,
         timestamp: str | datetime | None = None,
-        client_customer_key: Optional[str] = None,
+        customer_key: Optional[str] = None,
         context: Optional[Dict[str, Any]] = None,
     ) -> Any:
         return await asyncio.to_thread(
             self.track,
-            api_id,
-            system_key,
+            service_key,
             usage,
             response_id=response_id,
             timestamp=timestamp,
-            client_customer_key=client_customer_key,
+            customer_key=customer_key,
             context=context,
         )
 
+    # ------------------------------------------------------------------
+    # LLM Tracking Methods
+    # ------------------------------------------------------------------
     def track_llm_usage(
         self,
-        api_id: str,
+        service_key: str,
         response: Any,
         *,
         response_id: Optional[str] = None,
         timestamp: str | datetime | None = None,
-        client_customer_key: Optional[str] = None,
+        customer_key: Optional[str] = None,
         context: Optional[Dict[str, Any]] = None,
     ) -> Any:
         """Extract usage from an LLM response and enqueue it.
 
         Parameters are identical to :meth:`track` except that ``response`` is
         the raw LLM client response.  Usage information is obtained via
-        :func:`get_usage_from_response` using the provided ``api_id``.
+        :func:`get_usage_from_response` using the provided ``service_key``.
         ``response`` is returned to allow call chaining. If a ``response_id`` was
         not provided and one is generated, it is attached to the response as
         ``response.aicm_response_id`` for convenience.
         """
+        vendor, api_id = self._get_vendor_api_mapping(service_key)
+
         usage = get_usage_from_response(response, api_id)
         if isinstance(usage, dict) and usage:
-            model = getattr(response, "model", None)
-            vendor_map = {
-                "openai_chat": "openai",
-                "openai_responses": "openai",
-                "anthropic": "anthropic",
-                "gemini": "google",
-            }
-            vendor_prefix = vendor_map.get(api_id)
-            system_key = (
-                f"{vendor_prefix}::{model}" if vendor_prefix and model else model
+            final_service_key = self._build_final_service_key(
+                service_key, api_id, response
             )
+
             track_result = self.track(
-                api_id,
-                system_key,
+                final_service_key,
                 usage,
                 response_id=response_id,
                 timestamp=timestamp,
-                client_customer_key=client_customer_key,
+                customer_key=customer_key,
                 context=context,
             )
-            try:
-                setattr(
-                    response,
-                    "aicm_response_id",
-                    track_result.get("result", {}).get("response_id"),
-                )
-                setattr(response, "aicm_track_result", track_result)
-            except Exception:
-                pass
+            self._attach_tracking_metadata(response, track_result)
         return response
 
+    def _attach_tracking_metadata(self, response: Any, track_result: Any) -> None:
+        """Safely attach tracking metadata to response object."""
+        try:
+            setattr(
+                response,
+                "aicm_response_id",
+                track_result.get("result", {}).get("response_id"),
+            )
+            setattr(response, "aicm_track_result", track_result)
+        except Exception:
+            pass
+
     async def track_llm_usage_async(
         self,
-        api_id: str,
+        service_key: str,
         response: Any,
         *,
         response_id: Optional[str] = None,
         timestamp: str | datetime | None = None,
-        client_customer_key: Optional[str] = None,
+        customer_key: Optional[str] = None,
         context: Optional[Dict[str, Any]] = None,
     ) -> Any:
         """Async version of :meth:`track_llm_usage`."""
         return await asyncio.to_thread(
             self.track_llm_usage,
-            api_id,
+            service_key,
             response,
             response_id=response_id,
             timestamp=timestamp,
-            client_customer_key=client_customer_key,
+            customer_key=customer_key,
             context=context,
         )
 
     def track_llm_stream_usage(
         self,
-        api_id: str,
+        service_key: str,
         stream: Any,
         *,
         response_id: Optional[str] = None,
         timestamp: str | datetime | None = None,
-        client_customer_key: Optional[str] = None,
+        customer_key: Optional[str] = None,
         context: Optional[Dict[str, Any]] = None,
     ):
         """Yield streaming events while tracking usage.
@@ -312,27 +355,32 @@ class Tracker:
         :func:`get_streaming_usage_from_response` and sent via :meth:`track` once
         available.
         """
-        model = getattr(stream, "model", None)
-        vendor_map = {
-            "openai_chat": "openai",
-            "openai_responses": "openai",
-            "anthropic": "anthropic",
-            "gemini": "google",
-        }
-        vendor_prefix = vendor_map.get(api_id)
-        system_key = f"{vendor_prefix}::{model}" if vendor_prefix and model else model
+        vendor, api_id = self._get_vendor_api_mapping(service_key)
+
         usage_sent = False
         for chunk in stream:
             if not usage_sent:
                 usage = get_streaming_usage_from_response(chunk, api_id)
                 if isinstance(usage, dict) and usage:
+                    # For streaming, try to get model from both stream and chunk
+                    chunk_with_model = type(
+                        "MockResponse",
+                        (),
+                        {
+                            "model": getattr(stream, "model", None)
+                            or getattr(chunk, "model", None)
+                        },
+                    )()
+                    final_service_key = self._build_final_service_key(
+                        service_key, api_id, chunk_with_model
+                    )
+
                     self.track(
-                        api_id,
-                        system_key,
+                        final_service_key,
                         usage,
                         response_id=response_id,
                         timestamp=timestamp,
-                        client_customer_key=client_customer_key,
+                        customer_key=customer_key,
                         context=context,
                     )
                     usage_sent = True
@@ -340,33 +388,48 @@ class Tracker:
 
     async def track_llm_stream_usage_async(
         self,
-        api_id: str,
+        service_key: str,
         stream: Any,
         *,
         response_id: Optional[str] = None,
         timestamp: str | datetime | None = None,
-        client_customer_key: Optional[str] = None,
+        customer_key: Optional[str] = None,
         context: Optional[Dict[str, Any]] = None,
     ):
         """Asynchronous version of :meth:`track_llm_stream_usage`."""
-        system_key = getattr(stream, "model", None)
+        vendor, api_id = self._get_vendor_api_mapping(service_key)
+
         usage_sent = False
         async for chunk in stream:
             if not usage_sent:
                 usage = get_streaming_usage_from_response(chunk, api_id)
                 if isinstance(usage, dict) and usage:
+                    # For streaming, try to get model from both stream and chunk
+                    chunk_with_model = type(
+                        "MockResponse",
+                        (),
+                        {
+                            "model": getattr(stream, "model", None)
+                            or getattr(chunk, "model", None)
+                        },
+                    )()
+                    final_service_key = self._build_final_service_key(
+                        service_key, api_id, chunk_with_model
+                    )
+
                     await self.track_async(
-                        api_id,
-                        system_key,
+                        final_service_key,
                         usage,
                         response_id=response_id,
                         timestamp=timestamp,
-                        client_customer_key=client_customer_key,
+                        customer_key=customer_key,
                         context=context,
                     )
                     usage_sent = True
             yield chunk
 
+    # ------------------------------------------------------------------
+    # Context Manager and Lifecycle Methods
     # ------------------------------------------------------------------
     def __enter__(self):
         """Context manager entry point."""
@@ -391,6 +454,5 @@ class Tracker:
         delivery across multiple trackers should manage the delivery lifecycle
         separately instead of relying on the tracker's context manager.
         """
-
         if getattr(self, "delivery", None) is not None:
             self.delivery.stop()
