@@ -345,85 +345,7 @@ def get_streaming_usage_from_response(chunk: Any, api_id: str) -> dict[str, Any]
     return _to_serializable_dict(usage)
 
 
-def extract_usage(response: Any) -> dict[str, Any]:
-    """Extract usage information from response if present.
-
-    This is a compatibility function that delegates to get_usage_from_response
-    with a generic approach for backward compatibility.
-    """
-    if response is None:
-        return {}
-
-    # Try to use the more specific API-aware function first
-    # For known API patterns, we can try to infer the API type
-    if hasattr(response, "usage") and hasattr(response.usage, "prompt_tokens"):
-        # Looks like OpenAI format
-        return get_usage_from_response(response, "openai_chat")
-    elif hasattr(response, "usage_metadata") or hasattr(response, "usageMetadata"):
-        # Looks like Gemini format
-        usage = get_usage_from_response(response, "gemini")
-        # Normalize Gemini usage to match server schema expectations
-        return usage
-    elif hasattr(response, "input_tokens") or hasattr(response, "inputTokens"):
-        # Looks like Anthropic/Bedrock format
-        return get_usage_from_response(response, "anthropic")
-
-    # Fallback to generic extraction
-    for attr in ("usage", "usage_metadata", "response_metadata"):
-        data = getattr(response, attr, None)
-        if data is not None:
-            return _to_serializable_dict(data)
-
-    # Handle dictionary responses
-    if isinstance(response, dict):
-        for key in ("usage", "usageMetadata"):
-            data = response.get(key)
-            if data:
-                return _to_serializable_dict(data)
-        metadata = response.get("metadata")
-        if isinstance(metadata, dict):
-            for key in ("usage", "usageMetadata"):
-                data = metadata.get(key)
-                if data:
-                    return _to_serializable_dict(data)
-
-    return {}
-
-
-def extract_stream_usage(stream: Any) -> tuple[dict[str, Any], Any]:
-    """Consume a streaming iterator and return (usage, final_item).
-
-    This function consumes the entire stream to get the final item,
-    then extracts usage information from it.
-    """
-    final: Any = None
-
-    # Consume the stream to get the final item
-    if hasattr(stream, "__iter__"):
-        for event in stream:
-            final = event
-
-    # Some SDKs provide helper methods to retrieve the final message/response
-    if final is None:
-        for attr in ("get_final_response", "get_final_message", "response"):
-            obj = getattr(stream, attr, None)
-            if callable(obj):
-                try:
-                    final = obj()
-                    break
-                except Exception:  # pragma: no cover - safety
-                    pass
-            elif obj is not None:
-                final = obj
-                break
-
-    usage = extract_usage(final)
-    return usage, final
-
-
 __all__ = [
     "get_usage_from_response",
     "get_streaming_usage_from_response",
-    "extract_usage",
-    "extract_stream_usage",
 ]
