@@ -52,7 +52,7 @@ def _wait_for_cleared_limits(
     Matching filters:
     - service_key exact match
     - api_key_id exact match
-    - optional client_customer_key exact match when provided
+    - optional customer_key exact match when provided
     """
     from aicostmanager.config_manager import ConfigManager
 
@@ -74,7 +74,7 @@ def _wait_for_cleared_limits(
             for e in events
             if e.get("service_key") == service_key
             and e.get("api_key_id") == api_key_id
-            and (client_key is None or e.get("client_customer_key") == client_key)
+            and (client_key is None or e.get("customer_key") == client_key)
         ]
         if not remaining:
             return True
@@ -141,7 +141,6 @@ def test_limits_immediate_end_to_end(
         # First call might not raise if server hasn't processed the limit yet
         try:
             tracker.track(
-                "openai_responses",
                 SERVICE_KEY,
                 payload,
                 response_id=getattr(resp, "id", None),
@@ -151,7 +150,6 @@ def test_limits_immediate_end_to_end(
             payload2 = get_usage_from_response(resp2, "openai_responses")
             with pytest.raises(UsageLimitExceeded):
                 tracker.track(
-                    "openai_responses",
                     SERVICE_KEY,
                     payload2,
                     response_id=getattr(resp2, "id", None),
@@ -165,7 +163,6 @@ def test_limits_immediate_end_to_end(
         payload3 = get_usage_from_response(resp3, "openai_responses")
         with pytest.raises(UsageLimitExceeded):
             tracker.track(
-                "openai_responses",
                 SERVICE_KEY,
                 payload3,
                 response_id=getattr(resp3, "id", None),
@@ -196,7 +193,6 @@ def test_limits_immediate_end_to_end(
         for attempt in range(3):
             try:
                 tracker.track(
-                    "openai_responses",
                     SERVICE_KEY,
                     payload4,
                     response_id=getattr(resp4, "id", None),
@@ -218,7 +214,6 @@ def test_limits_immediate_end_to_end(
         payload5 = get_usage_from_response(resp5, "openai_responses")
         try:
             tracker.track(
-                "openai_responses",
                 SERVICE_KEY,
                 payload5,
                 response_id=getattr(resp5, "id", None),
@@ -278,7 +273,6 @@ def test_limits_queue_end_to_end(
         payload = get_usage_from_response(resp, "openai_responses")
         try:
             tracker.track(
-                "openai_responses",
                 SERVICE_KEY,
                 payload,
                 response_id=getattr(resp, "id", None),
@@ -295,7 +289,6 @@ def test_limits_queue_end_to_end(
         payload2 = get_usage_from_response(resp2, "openai_responses")
         with pytest.raises(UsageLimitExceeded):
             tracker.track(
-                "openai_responses",
                 SERVICE_KEY,
                 payload2,
                 response_id=getattr(resp2, "id", None),
@@ -324,7 +317,6 @@ def test_limits_queue_end_to_end(
         for attempt in range(3):
             try:
                 tracker.track(
-                    "openai_responses",
                     SERVICE_KEY,
                     payload3,
                     response_id=getattr(resp3, "id", None),
@@ -348,7 +340,6 @@ def test_limits_queue_end_to_end(
         payload4 = get_usage_from_response(resp4, "openai_responses")
         try:
             tracker.track(
-                "openai_responses",
                 SERVICE_KEY,
                 payload4,
                 response_id=getattr(resp4, "id", None),
@@ -419,22 +410,20 @@ def test_limits_customer_immediate(
         # First call might not raise if server hasn't processed the limit yet
         try:
             tracker.track(
-                "openai_responses",
                 SERVICE_KEY,
                 payload,
                 response_id=getattr(resp, "id", None),
-                client_customer_key=customer,
+                customer_key=customer,
             )
             # If first call doesn't raise, the second one should
             resp2 = client.responses.create(model=MODEL, input="hi2")
             payload2 = get_usage_from_response(resp2, "openai_responses")
             with pytest.raises(UsageLimitExceeded):
                 tracker.track(
-                    "openai_responses",
                     SERVICE_KEY,
                     payload2,
                     response_id=getattr(resp2, "id", None),
-                    client_customer_key=customer,
+                    customer_key=customer,
                 )
         except UsageLimitExceeded:
             # First call raised as expected
@@ -445,11 +434,10 @@ def test_limits_customer_immediate(
         payload3 = get_usage_from_response(resp3, "openai_responses")
         with pytest.raises(UsageLimitExceeded):
             tracker.track(
-                "openai_responses",
                 SERVICE_KEY,
                 payload3,
                 response_id=getattr(resp3, "id", None),
-                client_customer_key=customer,
+                customer_key=customer,
             )
 
         # Cleanup
@@ -477,11 +465,10 @@ def test_limits_customer_immediate(
         for attempt in range(3):
             try:
                 tracker.track(
-                    "openai_responses",
                     SERVICE_KEY,
                     payload4,
                     response_id=getattr(resp4, "id", None),
-                    client_customer_key=customer,
+                    customer_key=customer,
                 )
                 break  # Success
             except UsageLimitExceeded:
