@@ -3,7 +3,6 @@ import sys
 import types
 from pathlib import Path
 
-
 PACKAGE_DIR = Path(__file__).resolve().parent.parent / "aicostmanager"
 
 # ``test_llm_wrappers`` loads the ``wrappers`` module without importing the
@@ -80,22 +79,30 @@ for name, module in _ORIGINAL_MODULES.items():
         sys.modules.pop(name, None)
 
 
+class DummyIniManager:
+    def get_option(self, section, option, fallback=None):
+        return fallback
+
+
 class DummyTracker:
     def __init__(self):
         self.calls = []
+        self.ini_manager = DummyIniManager()
 
-    def track(self, api_id, service_key, usage, **kwargs):
-        self.calls.append((api_id, service_key, usage))
+    def track(self, service_key, usage, **kwargs):
+        self.calls.append((service_key, usage))
 
-    async def track_async(self, api_id, service_key, usage, **kwargs):
-        self.calls.append((api_id, service_key, usage))
+    async def track_async(self, service_key, usage, **kwargs):
+        self.calls.append((service_key, usage))
 
     def close(self):
         pass
 
 
 def _stream_chunk():
-    yield types.SimpleNamespace(usage={"prompt_tokens": 1, "completion_tokens": 1, "total_tokens": 2})
+    yield types.SimpleNamespace(
+        usage={"prompt_tokens": 1, "completion_tokens": 1, "total_tokens": 2}
+    )
     yield types.SimpleNamespace(data="done")
 
 
@@ -226,11 +233,10 @@ def test_wrappers_track_non_streaming():
         tracker.calls.clear()
         wrapper = wrapper_cls(client, tracker=tracker)
         obj = wrapper
-        for attr in call_path.split('.'):
+        for attr in call_path.split("."):
             obj = getattr(obj, attr)
         obj(**kwargs)
-        assert tracker.calls and tracker.calls[0][0] == wrapper_cls.api_id
-        assert tracker.calls[0][1] == expected
+        assert tracker.calls and tracker.calls[0][0] == expected
 
 
 def test_openai_chat_wrapper_streaming_tracks_once():
@@ -239,8 +245,7 @@ def test_openai_chat_wrapper_streaming_tracks_once():
     wrapper = OpenAIChatWrapper(client, tracker=tracker)
     stream = wrapper.chat.completions.create(model="gpt-4", stream=True)
     list(stream)
-    assert tracker.calls and tracker.calls[0][0] == "openai_chat"
-    assert tracker.calls[0][1] == "openai::gpt-4"
+    assert tracker.calls and tracker.calls[0][0] == "openai::gpt-4"
 
 
 def test_openai_chat_vendor_detection():
@@ -248,10 +253,10 @@ def test_openai_chat_vendor_detection():
     fw_client = make_openai_chat_client("https://api.fireworks.ai")
     wrapper_fw = OpenAIChatWrapper(fw_client, tracker=tracker)
     wrapper_fw.chat.completions.create(model="m1")
-    assert tracker.calls[0][1] == "fireworks-ai::m1"
+    assert tracker.calls[0][0] == "fireworks-ai::m1"
 
     tracker.calls.clear()
     x_client = make_openai_chat_client("https://api.x.ai")
     wrapper_x = OpenAIChatWrapper(x_client, tracker=tracker)
     wrapper_x.chat.completions.create(model="m2")
-    assert tracker.calls[0][1] == "xai::m2"
+    assert tracker.calls[0][0] == "xai::m2"
